| Title: | Slackr for Open Justice Oklahoma |
|---|---|
| Description: | This package is a wrapper for the [{slackr}](https://github.com/mrkaye97/slackr) package that allows for easy posting and analysis of messages, plots, and more on the Open Justice Oklahoma Slack workspace. |
| Authors: | Brancen Gregory [aut, cre] |
| Maintainer: | Brancen Gregory <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-30 09:12:11 UTC |
| Source: | https://github.com/openjusticeok/ojoslackr |
Add a watermark to a ggplot2 plot
ojo_watermark( text = "DRAFT", fontsize = 120, color = "grey90", alpha = 0.1, fontface = "bold", angle = 22 )ojo_watermark( text = "DRAFT", fontsize = 120, color = "grey90", alpha = 0.1, fontface = "bold", angle = 22 )
text |
String to be added as watermark |
fontsize |
Font size |
color |
Font color |
alpha |
Alpha (transparency; lower number = more transparent) |
fontface |
Font face ("bold" by default) |
angle |
Angle of the watermark |
## Not run: library(ojodb) library(ggplot2) library(grid) ojo_tbl("case") |> head(10) |> ojo_collect() |> ggplot(aes(x = date_filed, y = date_closed)) + geom_point() + ojo_theme() + ojo_watermark("DRAFT") ## End(Not run)## Not run: library(ojodb) library(ggplot2) library(grid) ojo_tbl("case") |> head(10) |> ojo_collect() |> ggplot(aes(x = date_filed, y = date_closed)) + geom_point() + ojo_theme() + ojo_watermark("DRAFT") ## End(Not run)